summaryrefslogtreecommitdiffstats
path: root/kpat/freecell-solver/intrface.c
diff options
context:
space:
mode:
Diffstat (limited to 'kpat/freecell-solver/intrface.c')
-rw-r--r--kpat/freecell-solver/intrface.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/kpat/freecell-solver/intrface.c b/kpat/freecell-solver/intrface.c
index 44aa29a0..9fb09840 100644
--- a/kpat/freecell-solver/intrface.c
+++ b/kpat/freecell-solver/intrface.c
@@ -796,7 +796,7 @@ static void trace_solution(
s1 = instance->final_state;
/* Retrace the step from the current state to its parents */
- while (s1->tqparent != NULL)
+ while (s1->parent != NULL)
{
/* Mark the state as part of the non-optimized solution */
s1->visited |= FCS_VISITED_IN_SOLUTION_PATH;
@@ -811,8 +811,8 @@ static void trace_solution(
}
/* Duplicate the state to a freshly malloced memory */
- /* Move to the tqparent state */
- s1 = s1->tqparent;
+ /* Move to the parent state */
+ s1 = s1->parent;
}
/* There's one more state than there are move stacks */
s1->visited |= FCS_VISITED_IN_SOLUTION_PATH;
@@ -915,7 +915,7 @@ int freecell_solver_solve_instance(
state_copy_ptr->depth = 0;
state_copy_ptr->moves_to_parent = NULL;
state_copy_ptr->visited = 0;
- state_copy_ptr->tqparent = NULL;
+ state_copy_ptr->parent = NULL;
memset(&(state_copy_ptr->scan_visited), '\0', sizeof(state_copy_ptr->scan_visited));
instance->state_copy_ptr = state_copy_ptr;